/***************************************************************************
                          job_querydatabase.h  -  description
                             -------------------
    begin                : Wed May 23 2001
    copyright            : (C) 2001 by Holger Sattel
    email                : hsattel@rumms.uni-mannheim.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef JOB_QUERYDATABASE_H
#define JOB_QUERYDATABASE_H

#include "prokyon.h"

#include "jobbase.h"

class Job_QueryDatabase : public JobBase  {
public:
    Job_QueryDatabase(int, int=0);
    Job_QueryDatabase(int, QString, QString);
    Job_QueryDatabase(int, QString, bool, bool, bool, bool, bool, bool);

    int type() {
        return JOB_QUERY_DATABASE;
    }

    void run();

    ~Job_QueryDatabase();

private:
    int querytype, queryID;
    QString querydata;
    QString querydata2;
    bool    byFilename, byArtist, byTitle, byAlbum, byComment, byNotes;
};

#endif
